@@ -2,7 +2,7 @@
 #'
 #' Compute indices of model performance for mixed models.
 #'
-#' @param metrics Can be \code{"all"} or a character vector of metrics to be computed (some of \code{c("AIC", "BIC", "R2", "ICC", "RMSE", "LOGLOSS", "SCORE")}).
+#' @param metrics Can be \code{"all"}, \code{"common"} or a character vector of metrics to be computed (some of \code{c("AIC", "BIC", "R2", "ICC", "RMSE", "LOGLOSS", "SCORE")}). \code{"common"} will compute AIC, BIC, R2, ICC and RMSE.
 #' @param ... Arguments passed to or from other methods.
 #' @inheritParams r2_nakagawa
 #' @inheritParams model_performance.lm
@@ -17,21 +17,24 @@
 #'   more details on returned indices.
 #'
 #' @examples
-#' library(lme4)
-#' model <- lmer(Petal.Length ~ Sepal.Length + (1 | Species), data = iris)
-#' model_performance(model)
+#' if (require("lme4")) {
+#'   model <- lmer(Petal.Length ~ Sepal.Length + (1 | Species), data = iris)
+#'   model_performance(model)
+#' }
 #' @importFrom insight model_info
 #' @export
 model_performance.merMod <- function(model, metrics = "all", verbose = TRUE, ...) {
   if (all(metrics == "all")) {
     metrics <- c("AIC", "BIC", "R2", "ICC", "RMSE", "LOGLOSS", "SCORE")
+  } else if (all(metrics == "common")) {
+    metrics <- c("AIC", "BIC", "R2", "ICC", "RMSE")
   }
 
   mi <- insight::model_info(model)
 
   out <- list()
   if ("AIC" %in% metrics) {
-    out$AIC <- .get_AIC(model)
+    out$AIC <- performance_aic(model)
   }
   if ("BIC" %in% metrics) {
     out$BIC <- .get_BIC(model)
@@ -82,3 +85,37 @@ model_performance.mixed <- model_performance.merMod
 
 #' @export
 model_performance.glmmTMB <- model_performance.merMod
+
+
+
+#' @export
+model_performance.mixor <- function(model, metrics = "all", verbose = TRUE, ...) {
+  if (all(metrics == "all")) {
+    metrics <- c("AIC", "BIC", "LOGLOSS", "SCORE")
+  }
+
+  mi <- insight::model_info(model)
+
+  out <- list()
+  if ("AIC" %in% metrics) {
+    out$AIC <- performance_aic(model)
+  }
+  if ("BIC" %in% metrics) {
+    out$BIC <- .get_BIC(model)
+  }
+  if (("LOGLOSS" %in% metrics) && mi$is_binomial && !mi$is_ordinal) {
+    out$LOGLOSS <- performance_logloss(model, verbose = verbose)
+  }
+  if (("SCORE" %in% metrics) && (mi$is_binomial || mi$is_count) && !mi$is_ordinal) {
+    .scoring_rules <- performance_score(model, verbose = verbose)
+    if (!is.na(.scoring_rules$logarithmic)) out$SCORE_LOG <- .scoring_rules$logarithmic
+    if (!is.na(.scoring_rules$spherical)) out$SCORE_SPHERICAL <- .scoring_rules$spherical
+  }
+
+  out <- as.data.frame(out)
+  row.names(out) <- NULL
+
+  out
+}
+
+
